@@ -112,7 +112,7 @@ our @ISA = qw(Exporter);
 #============================================================================================
 # GLOBALS
 #============================================================================================
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 our $AUTOLOAD ;
 
 #============================================================================================
@@ -2119,7 +2119,9 @@ sub read_dvb_pr
 	my %chans ;
 	foreach (keys %dvb_pr)
 	{
-		$chans{ $dvb_pr{$_}{'name'} } = $dvb_pr{$_} ; 
+		# handle chans with no name
+		my $name = $dvb_pr{$_}{'name'} || $_ ; 
+		$chans{$name} = $dvb_pr{$_} ; 
 	}
 	
 	return \%chans ;
